summaryrefslogtreecommitdiff
path: root/src/ostree/ot-builtin-checkout.c
diff options
context:
space:
mode:
authorGiuseppe Scrivano <gscrivan@redhat.com>2016-07-27 11:34:22 +0200
committerAtomic Bot <atomic-devel@projectatomic.io>2016-07-30 11:24:52 +0000
commitedecae06ab65f139cddbb701cb37b672715bb176 (patch)
tree9e9e5bc2ce6c5d1453c6b4e415fa9b68db3b37a9 /src/ostree/ot-builtin-checkout.c
parent0bac88e13209001b478fe771749441526095cb0a (diff)
downloadostree-edecae06ab65f139cddbb701cb37b672715bb176.tar.gz
libostree, ostree: fix usage of ostree_repo_checkout_tree_at
it was deprecated, use ostree_repo_checkout_at. Signed-off-by: Giuseppe Scrivano <gscrivan@redhat.com> Closes: #417 Approved by: cgwalters
Diffstat (limited to 'src/ostree/ot-builtin-checkout.c')
-rw-r--r--src/ostree/ot-builtin-checkout.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/ostree/ot-builtin-checkout.c b/src/ostree/ot-builtin-checkout.c
index c6fdf1fc..21e568b2 100644
--- a/src/ostree/ot-builtin-checkout.c
+++ b/src/ostree/ot-builtin-checkout.c
@@ -84,12 +84,12 @@ process_one_checkout (OstreeRepo *repo,
/* This strange code structure is to preserve testing
* coverage of both `ostree_repo_checkout_tree` and
* `ostree_repo_checkout_tree_at` until such time as we have a more
* convenient infrastructure for testing C APIs with data.
*/
if (opt_disable_cache || opt_whiteouts || opt_require_hardlinks)
{
- OstreeRepoCheckoutOptions options = { 0, };
+ OstreeRepoCheckoutAtOptions options = { 0, };
if (opt_user_mode)
options.mode = OSTREE_REPO_CHECKOUT_MODE_USER;
@@ -101,10 +101,10 @@ process_one_checkout (OstreeRepo *repo,
options.subpath = subpath;
options.no_copy_fallback = opt_require_hardlinks;
- if (!ostree_repo_checkout_tree_at (repo, &options,
- AT_FDCWD, destination,
- resolved_commit,
- cancellable, error))
+ if (!ostree_repo_checkout_at (repo, &options,
+ AT_FDCWD, destination,
+ resolved_commit,
+ cancellable, error))
goto out;
}
else
@@ -84,12 +84,12 @@ process_one_checkout (OstreeRepo *repo,
/* This strange code structure is to preserve testing
* coverage of both `ostree_repo_checkout_tree` and
- * `ostree_repo_checkout_tree_at` until such time as we have a more
+ * `ostree_repo_checkout_at` until such time as we have a more
* convenient infrastructure for testing C APIs with data.
*/